SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[BulkProgress]
AS
BEGIN
	INSERT INTO [Progress] ([Key]
		  ,[VCC]
		  ,[ProcessId]
		  ,[Type]
		  ,[TypeId]
		  ,[Total]
		  ,[Progress]
		  ,[Error]
		  ,[Percentage]
		  ,[StatusDescription])  
	SELECT [Key]
		  ,[VCC]
		  ,[ProcessId]
		  ,[Type]
		  ,[TypeId]
		  ,[Total]
		  ,[Progress]
		  ,[Error]
		  ,[Percentage]
		  ,[StatusDescription]
	  FROM [dbo].[#ProgressTemp]
	  
	------------Estados de procesos --------------
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = CASE WHEN B.[Total] > 0 THEN B.[Percentage] ELSE 0 END
		,[StatusDescription] = CASE WHEN B.[Total] >= 0 AND B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Total] >= 0 AND B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
		,[LastModifiedDate] = GETUTCDATE()
	FROM Process AS A
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON A.[vcc] = B.[vcc] 
			AND A.[Name] = B.ProcessId 
			AND B.[Type] IS NULL 

	UPDATE A
	SET [Status] = CASE 
			WHEN B.total >= 0 AND B.total <= B.transcription + B.cancel AND B.cancel > B.transcription THEN 'FAILED' 
			WHEN B.total >= 0 AND B.total <= B.transcription + B.cancel THEN 'COMPLETE' 
			ELSE 'INPROCESS_TRANSCRIPTION' 
			END
		,[LastModifiedDate] = GETUTCDATE()
	FROM Process AS A
	INNER JOIN (
		SELECT SUM(UT.total)					'total',
				SUM(UT.cancel)					'cancel',
				SUM(UT.transcription)			'transcription',
				UT.processId					'processId',
				UT.vcc							'vcc'
			FROM (
			  SELECT 
				COUNT(1)					total
				,COUNT(C.isCancel)			cancel
				,COUNT(C.IsTranscribed)		transcription 
				,B.ProcessId				processId
				,B.vcc						vcc
			  FROM [ProcessAudio] A (NOLOCK)
			  INNER JOIN [#ProgressTemp] B 
				ON A.[vcc] = B.[vcc] 
					AND A.ProcessId = B.ProcessId 
					AND B.[Type] IS NULL 
					AND B.[Percentage] = 1
			  INNER JOIN Audio C (NOLOCK) 
				ON A.VCC = C.VCC 
					AND A.AudioId =C.ID 
					AND ISNULL(A.Section,0) = ISNULL(C.Section,0) 
					AND ISNULL(A.Part,0) = ISNULL(C.Part,0)
			  GROUP BY B.ProcessId, B.vcc
			  UNION
			  SELECT 
			  COUNT(1)						total
			  ,COUNT(AI.IsCancel)			cancel
			  ,COUNT(AI.IsTranscribed)		transcription
			  ,PT.[ProcessId]				processId
			  ,PT.[vcc]						vcc
			  FROM [ProcessAsyncInteraction] PAI (NOLOCK)
			  INNER JOIN [#ProgressTemp] PT
				ON PAI.[VCC] = PT.[vcc]
					AND PAI.[ProcessId] = PT.[ProcessId]
					AND PT.[Percentage] = 1
			  INNER JOIN [AsyncInteraction] AI (NOLOCK) 
				ON AI.[VCC] = PT.[vcc]
					AND AI.[Channel] = PAI.[InteractionType]
					AND AI.[Folder] = PAI.[FormattedEndDate]
					AND AI.[Campaign] = PAI.[Campaign]
					AND AI.[ID] = PAI.[InteractionId]
			  GROUP BY PT.ProcessId, PT.vcc
		) UT GROUP BY UT.processId, UT.vcc

	  ) B ON A.[vcc] = B.[vcc] 
		AND A.[Name] = B.ProcessId

	UPDATE P
		SET P.[Status] = CASE WHEN TMPP.[totalFailed] > TMPP.[totalSucced] THEN 'FAILED'
								ELSE 'COMPLETE' END,
			P.[StatusDescription] = CASE WHEN TMPP.[totalFailed] > 0 THEN 'COMPLETED_WITH_ERROR' 
											ELSE 'COMPLETED' END,
			P.[Percentage] = 1
			,P.[LastModifiedDate] = GETUTCDATE()
		FROM [dbo].[Process] P (NOLOCK)
		INNER JOIN (
			SELECT UT.[processId]							'processId',
					ISNULL(SUM(UT.[totalAudio]), 0)			'totalAudio',
					ISNULL(SUM(UT.[totalSucced]), 0)		'totalSucced',
					ISNULL(SUM(UT.[totalFailed]), 0)		'totalFailed'
				FROM (
					SELECT P.[Name] 'processId',
							COUNT(*) 'totalAudio',
							COUNT(CASE WHEN ISNULL(A.[IsTranscribed], 0) = 1 THEN 1 ELSE NULL END) 'totalSucced',
							COUNT(CASE WHEN ISNULL(A.[IsCancel], 0) = 1 THEN 1 ELSE NULL END) 'totalFailed'
						FROM [dbo].[Process] P (NOLOCK) 
						INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
							ON PA.[ProcessId] = P.[Name]
						INNER JOIN [dbo].[Audio] A (NOLOCK) 
							ON A.[ID] = PA.[AudioId]
								AND A.[Section] = PA.[Section]
								AND A.[Part] = PA.[Part]
						WHERE (P.[StatusDescription] <> 'COMPLETED' AND P.[Status] <> 'COMPLETE')
							OR (P.[StatusDescription] = 'COMPLETED' AND P.[Status] <> 'COMPLETE')
							OR (P.[StatusDescription] = 'COMPLETED' AND P.[Status] IS NULL)
							OR (P.[Total] = 0 AND P.[Percentage] = 0)
							-- AND P.[Status] = 'INPROCESS_TRANSCRIPTION'
							--AND P.[StatusDescription] = 'IN_PROGRESS'
						GROUP BY P.[Name]
			
					UNION

					SELECT P.[Name],
							COUNT(*) 'totalAudio',
							COUNT(CASE WHEN ISNULL(AI.[IsTranscribed], 0) = 1 THEN 1 ELSE NULL END) 'totalSucced',
							COUNT(CASE WHEN ISNULL(AI.[IsCancel], 0) = 1 THEN 1 ELSE NULL END) 'totalFailed'
						FROM [dbo].[Process] P (NOLOCK) 
						INNER JOIN [ProcessAsyncInteraction] PAI (NOLOCK)
							ON PAI.[VCC] = P.[vcc]
								AND PAI.[ProcessId] = P.[Name]
						INNER JOIN [AsyncInteraction] AI (NOLOCK) 
							ON AI.[VCC] = P.[vcc]
								AND AI.[Channel] = PAI.[InteractionType]
								AND AI.[Folder] = PAI.[FormattedEndDate]
								AND AI.[Campaign] = PAI.[Campaign]
								AND AI.[ID] = PAI.[InteractionId]
						WHERE (P.[StatusDescription] <> 'COMPLETED' AND P.[Status] <> 'COMPLETE')
							OR (P.[StatusDescription] = 'COMPLETED' AND P.[Status] <> 'COMPLETE')
							OR (P.[StatusDescription] = 'COMPLETED' AND P.[Status] IS NULL)
							OR (P.[Total] = 0 AND P.[Percentage] = 0)
						GROUP BY P.[Name]
					) UT GROUP BY UT.[processId]
		) TMPP
			ON TMPP.[processId] = P.[Name]
				AND TMPP.[totalAudio] = (ISNULL(TMPP.[totalSucced], 0) + ISNULL(TMPP.[totalFailed], 0))


	-- REGISTROS DE [dbo].[#ProgressTemp] CON [Percentage] = 1 YA ESTAN TERMINADO (CON O SIN ERRORES)
	-- SI EL PROCESS SE MARCA COMO FAILED TUVO MUCHO FRACASOS, PERO AUN ASI TUVO EXITOS QUE DEBERERIA COBRARSE
	INSERT INTO [dbo].[Batch] ([VCC], [BatchTypeName], [BatchTypeId], [IsFinished], [ClosedDate], [LastModifiedDate])
		SELECT PTMP.[vcc], 'TRANSCRIPTION', PTMP.[ProcessId], 1, GETUTCDATE(), GETUTCDATE()
			FROM [#ProgressTemp] PTMP
			INNER JOIN [dbo].[Process] P 
				ON P.[vcc] = PTMP.[vcc] 
					AND P.[Name] = PTMP.[ProcessId] 
					AND PTMP.[Type] IS NULL
			WHERE PTMP.[Percentage] = 1 
				AND PTMP.[Type] IS NULL
	
	------------ESTADOS DE ESTUDIOS --------------
	UPDATE A
		SET [Total] = B.[Total]
			,[progress] = B.[Progress]
			,[error] = B.[Error]
			,[percentage] = B.[Percentage]
			,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
										WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
										ELSE  'IN_PROGRESS' END
			,[Status] = B.[Percentage]
			,[LastModifiedDate] = GETUTCDATE()
			--,[BatchStatus] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'FINISHED_WITH_ERROR' 
				--					WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'FINISHED' 
					--				ELSE 'RUNNING' END
		FROM Study AS A
		INNER JOIN [dbo].[#ProgressTemp] B 
			ON A.[vcc] = B.[vcc] 
				AND A.[ProcessId] = B.ProcessId 
				AND A.[Name] = B.[TypeId] 
				AND B.[Type] = 'study'

	-- REGISTROS DE [dbo].[#ProgressTemp] CON [Percentage] = 1 YA ESTAN TERMINADO (CON O SIN ERRORES)
	INSERT INTO [dbo].[Batch] ([VCC], [BatchTypeName], [BatchTypeId], [IsFinished], [ClosedDate], [LastModifiedDate])
		SELECT PTMP.[vcc], 'STUDY', PTMP.[TypeId], 1, GETUTCDATE(), GETUTCDATE()
			FROM [#ProgressTemp] PTMP
			INNER JOIN [dbo].[Study] S 
				ON S.[vcc] = PTMP.[vcc] 
					AND S.[ProcessId] = PTMP.[ProcessId] 
					AND S.[Name] = PTMP.[TypeId]
					AND PTMP.[Type] = 'study'
			WHERE PTMP.[Percentage] = 1 
				AND PTMP.[Type] = 'study'

	------------Estados de plan de evaluacion --------------

	-- UPDATE PARA LA PARTE DE TRANSCRIPCION
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE 'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 3 ELSE 2 END
		,[LastModifiedDate] = GETUTCDATE()
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON A.[Instance] = B.[vcc] 
			AND A.[ProcessId] = B.ProcessId 
			AND B.[Type] IS NULL 
			AND A.[FilterByContentQueryName] IS NOT NULL 
			AND A.[FilterByContentQuery] IS NOT NULL

	-- UPDATE CONTEMPLADO PARA PLAN DE EVALUACION CON PASO 3 (FILTRO DE CONTENIDO)
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 5 ELSE 4 END
		,[LastModifiedDate] = GETUTCDATE()
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON A.[Instance] = B.[vcc] 
			AND A.[ProcessId] = B.ProcessId 
			AND A.Id = B.[TypeId] 
			AND B.[Type] = 'evaluationPlan'

	-- UPDATE PARA LA PARTE DE ANALISIS SEMANTICO/COGNITIVO
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 5 ELSE 2 END
		,[LastModifiedDate] = GETUTCDATE()
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B ON A.[Instance] = B.[vcc] 
	AND A.[ProcessId] = B.ProcessId 
	AND B.[Type] IS NULL 
	AND A.[FilterByContentQueryName] IS NULL 
	AND A.[FilterByContentQuery] IS NULL 
	AND (
		A.[Evaluation_Mode] = 'A' 
		OR
		A.[Evaluation_Mode] = 'X'
	)

	-- ACTUALIZAMOS EL ESTADO DE LOS PLANES DE LA TABLA TEMPORAL
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 7 ELSE 6 END
		,[LastModifiedDate] = GETUTCDATE() 
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON A.[Instance] = B.[vcc] 
			AND A.[ProcessId] = B.ProcessId 
			AND A.Id = B.[TypeId] 
			AND B.[Type] = 'ability'

	-- EN UNA TABLA ADICIONAL PODRIA INSERTAR LOS RP STATUS 7 PARA LUEGO ENVIARLOS A CERRAR EN EL SC
	UPDATE AEP 
		SET AEP.[Completed] = 1
			,[LastModifiedDate] = GETUTCDATE()
	FROM dbo.[AuditorEvaluationPlan] AEP 
	INNER JOIN dbo.[EvaluationPlan] EP 
		ON EP.[ID] = AEP.[IdEvaluationPlan]
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON EP.[Instance] = B.[vcc] 
			AND EP.[ProcessId] = B.ProcessId 
			AND EP.Id = B.[TypeId] 
			AND B.[Type] = 'ability'
	WHERE EP.[Status] = 7
		AND AEP.[IdAuditor] = 'SPEECH' 
		AND (EP.[Evaluation_Mode] = 'A' OR EP.[Evaluation_Mode] = 'X') 

	-- REGISTROS DE [dbo].[#ProgressTemp] CON [Percentage] = 1 YA ESTAN TERMINADO (CON O SIN ERRORES)
	INSERT INTO [dbo].[Batch] ([VCC], [BatchTypeName], [BatchTypeId], [IsFinished], [ClosedDate], [LastModifiedDate])
		SELECT PTMP.[vcc], 'EVALUATION_PLAN', PTMP.[TypeId], 1, GETUTCDATE(), GETUTCDATE()
			FROM [#ProgressTemp] PTMP
			INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON EP.[Instance] = PTMP.[vcc] 
					AND EP.[ProcessId] = PTMP.[ProcessId] 
					AND EP.[Id] = PTMP.[TypeId]
					AND (PTMP.[Type] = 'ability' OR PTMP.[Type] = 'evaluationPlan')
			WHERE PTMP.[Percentage] = 1 
				AND (PTMP.[Type] = 'ability' OR PTMP.[Type] = 'evaluationPlan')

	-- INICIO MEDIDA PARA PLANES FINALIZADOS QUE NO TIENE RESULTS REGISTRADOS
	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT PTMP.[vcc] 'VCC', 
				PTMP.[TypeId] 'EVALUATION_PLAN_ID'
			FROM [#ProgressTemp] PTMP
			INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON EP.[Instance] = PTMP.[vcc] 
					AND EP.[ProcessId] = PTMP.[ProcessId] 
					AND EP.[Id] = PTMP.[TypeId]
					AND (PTMP.[Type] = 'ability' OR PTMP.[Type] = 'evaluationPlan')
			WHERE PTMP.[Percentage] = 1 
				AND (PTMP.[Type] = 'ability' OR PTMP.[Type] = 'evaluationPlan')
			
	-- DECLARARAMOS VARIABLES PARA INDICAR EL PLAN Y VCC
	DECLARE @CURRENT_VCC VARCHAR(50) = ''
	DECLARE @CURRENT_EVALUATION_PLAN_ID VARCHAR(100) = ''
	DECLARE @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION NUMERIC(5, 2) = 0

	-- ABRIMOS Y RECORREMOS EL ARRAY DE CANALES
	OPEN MY_CURSOR
	FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- BUSCAMOS SI EXISTE RESULTS PARA EL PLAN ACTUAL
		IF NOT EXISTS (
			SELECT 1 
				FROM [dbo].[EvaluationResult] ER (NOLOCK) 
				WHERE ER.[Instance] = @CURRENT_VCC
					AND ER.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
		)
		BEGIN
			-- EJECUTAMOS EL SP QUE INSERTA LOS RESULT BASE DE LOS PLANES QUE AUN NO LOS TIENEN
			EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'AUTOMATIC'

			-- ACTUALIZAMOS A COMPLETED LOS REGISTROS AUDITOR_EVALUATION_PLAN DEL PLAN ACTUAL
			UPDATE AEP
				SET AEP.[Completed] = '1'
				FROM AuditorEvaluationPlan AEP (NOLOCK)
				WHERE AEP.[Instance] = @CURRENT_VCC
					AND AEP.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
		END

		FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	END
	CLOSE MY_CURSOR
	DEALLOCATE MY_CURSOR
	-- FIN MEDIDA PARA PLANES FINALIZADOS QUE NO TIENE RESULTS REGISTRADOS





	-- INICIO DE ACTUALIZACION DE ESTADO PARA PLANES MIXTOS(TERMINADA LA FASE AUTOMATICA(ESTADO 7), PASA A LA MANUAL(ESTADO 8) Y ACABADA LA MANUAL REGRESA AL ESTADO 7)

	DECLARE @CURRENT_AUDITOR_ID VARCHAR(50) = ''

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR_2 CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT DISTINCT
				PT.[vcc]								'VCC', 
				PT.[TypeId]								'EVALUATION_PLAN_ID',
				EF.[MinAutomaticQualification]			'MIN_AUTOMATIC_QUALIFICATION'
			FROM [dbo].[EvaluationPlan] AS EP (NOLOCK)
			INNER JOIN [dbo].[#ProgressTemp] PT 
				ON EP.[Instance] = PT.[vcc] 
					AND EP.[ProcessId] = PT.[ProcessId] 
					AND EP.[Id] = PT.[TypeId] 
					AND PT.[Type] = 'ability'
			INNER JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = EP.[Instance]
					AND EF.[ID] = EP.[IdEvaluationFormat]
			WHERE EP.[Status] = 7
				AND EP.[Evaluation_Mode] = 'X'

	-- ABRIMOS Y RECORREMOS EL ARRAY DE PLANES
	OPEN MY_CURSOR_2
	FETCH NEXT FROM MY_CURSOR_2 INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- EVALUAMOS SI EL AUDITOR SPEECH CALIFICO CON NOTA MAYOR O IGUAL AL ACEPTABLE MINIMO PARA LA PARTE AUTOMATICA
		IF EXISTS (
			SELECT 1
				FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
				WHERE AEP.[Instance] = @CURRENT_VCC
					AND AEP.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
					AND AEP.[IdAuditor] = 'SPEECH'
					AND AEP.[Score] >= @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION
		)
		BEGIN
			-- ACTUALIZAMOS EL ESTADO DEL PLAN MIXTO PARA PASAR A LA PARTE MANUAL
			UPDATE EP 
				SET EP.[percentage] = 0
					,EP.[StatusDescription] = 'IN_PROGRESS'
					,EP.[Status] = 8
					,EP.[LastModifiedDate] = GETUTCDATE() 
				FROM [dbo].[EvaluationPlan] AS EP (NOLOCK)
				WHERE EP.[Instance] = @CURRENT_VCC
					AND EP.[ID] = @CURRENT_EVALUATION_PLAN_ID

			-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS ID DE AUDITORES CORRESPONDIENTES AL PLAN
			DECLARE MY_AUDITOR_CURSOR CURSOR 
			LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
				FOR 
				-- CONSULTAMOS LOS ID DE AUDITORES
				SELECT DISTINCT AEP.[IdAuditor]
					FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
					WHERE  AEP.[Instance] = @CURRENT_VCC
						AND AEP.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
						AND AEP.[IdAuditor] <> 'SPEECH'

			-- ABRIMOS Y RECORREMOS EL ARRAY DE PLANES
			OPEN MY_AUDITOR_CURSOR
			FETCH NEXT FROM MY_AUDITOR_CURSOR INTO @CURRENT_AUDITOR_ID
			WHILE @@FETCH_STATUS = 0
			BEGIN 
				-- INSERTARMOS LOS REGISTROS DE ER QUE TENIA EL AUDITOR SPEECH
				INSERT INTO [dbo].[EvaluationResult] (
					[Instance], [IdCampaign], [IdInteraction], [IdAgent], [IdEvaluationFormat],
					[MinQualificationAcceptable], [IdGroup], [IdSubGroup], [IdAbility], [Qualification],
					[IdEvaluator], [EvaluationDate], [MaxAbilityScore], [IdEvaluationPlan], [CreatedDate],
					[CreatedByUserId], [TimeStamp], [NotApplies], [ScoreDescription], [CampaignDescription],
					[AgentDescription], [InteractionDateini], [InteractionDatefin], [InteractionAddress], [AbilityOrder],
					[InteractionType], [IdAbilityEvaluationFormat], [IdAuditor], [Conditional]
				) 
					-- SELECCIONAMOS LOS RESULTADOS REGISTRADOS POR SPEECH
					SELECT ER.[Instance], ER.[IdCampaign], ER.[IdInteraction], ER.[IdAgent], ER.[IdEvaluationFormat],
							ER.[MinQualificationAcceptable], ER.[IdGroup], ER.[IdSubGroup], ER.[IdAbility], ER.[Qualification],
							ER.[IdEvaluator], ER.[EvaluationDate], ER.[MaxAbilityScore], ER.[IdEvaluationPlan], ER.[CreatedDate],
							ER.[CreatedByUserId], GETUTCDATE(), ER.[NotApplies], ER.[ScoreDescription], ER.[CampaignDescription],
							ER.[AgentDescription], ER.[InteractionDateini], ER.[InteractionDatefin], ER.[InteractionAddress], ER.[AbilityOrder],
							ER.[InteractionType], ER.[IdAbilityEvaluationFormat], @CURRENT_AUDITOR_ID, ER.[Conditional]
						FROM [dbo].[EvaluationResult] ER (NOLOCK)
						INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
							ON AEP.[Instance] = ER.[Instance]
								AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
								AND AEP.[IdAuditor] = ER.[IdAuditor]
								AND AEP.[IdInteraction] = ER.[IdInteraction]
								AND AEP.[Score] >= @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION
						WHERE ER.[Instance] = @CURRENT_VCC
							AND ER.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
							AND ER.[IdAuditor] = 'SPEECH'

				-- REABRIMOS LAS EVALUACIONES DE LAS INTERACCIONES CON SCORE MAYOR O IGUAL AL UMBRAL
				UPDATE [dbo].[AuditorEvaluationPlan]
					SET [Completed] = 0,
						[AutomaticScore] = [Score],
						[ManualScore] = 0,
						[LastModifiedDate] = GETUTCDATE(),
						[TimeStamp] = GETUTCDATE()
					WHERE [Instance] = @CURRENT_VCC
						AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
						AND [IdAuditor] = @CURRENT_AUDITOR_ID

				FETCH NEXT FROM MY_AUDITOR_CURSOR INTO @CURRENT_AUDITOR_ID
			END
			CLOSE MY_AUDITOR_CURSOR
			DEALLOCATE MY_AUDITOR_CURSOR

			-- COMPLETAMOS LOS REGISTROS DE ER PARA LAS HABILIDADES MANUALES <- LAS HAB. MANUALES DEBEN QUEDAN EN BLANCO PARA EL AUDITOR SPEECH
			-- EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'MANUAL'

			-- REMOVEMOS LOS REGISTROS DE SPEECH (AEP Y ER) QUE FUERON ASIGNADOS A LOS AUDITORES
			DELETE ER
				FROM [dbo].[EvaluationResult] ER
				INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
					ON AEP.[Instance] = ER.[Instance]
						AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
						AND AEP.[IdInteraction] = ER.[IdInteraction]
						AND AEP.[Score] >= @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION
				WHERE ER.[Instance] = @CURRENT_VCC
					AND ER.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
					AND ER.[IdAuditor] = 'SPEECH'
					AND AEP.[Score] >= @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION

			-- REMOVEMOS LOS REGISTROS DE SPEECH EN AEP QUE PASARON EL MINIMO PARA AUTOMATICO
			DELETE 
				FROM [dbo].[AuditorEvaluationPlan] 
				WHERE [Instance] = @CURRENT_VCC
					AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
					AND [IdAuditor] = 'SPEECH'
					AND [Score] >= @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION

			-- REMOVEMOS LOS REGISTROS DE LOS OTROS AUDITORES QUE NO PASARON EL MINIMO PARA AUTOMATICO
			DELETE 
				FROM [dbo].[AuditorEvaluationPlan] 
				WHERE [Instance] = @CURRENT_VCC
					AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
					AND [IdAuditor] <> 'SPEECH'
					AND [IdInteraction] IN (
						SELECT [IdInteraction] 
							FROM [dbo].[AuditorEvaluationPlan] 
							WHERE [Instance] = @CURRENT_VCC
								AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
								AND [IdAuditor] = 'SPEECH'
								AND [Score] < @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION
					)

			-- ACTUALIZAMOS LOS CAMPOS SCORE DE LAS EVALUACIONES DE SPEECH
			UPDATE [dbo].[AuditorEvaluationPlan]
					SET [AutomaticScore] = [Score],
						[ManualScore] = 0,
						[LastModifiedDate] = GETUTCDATE(),
						[TimeStamp] = GETUTCDATE()
					WHERE [Instance] = @CURRENT_VCC
						AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
						AND [IdAuditor] = 'SPEECH'

		END
		ELSE
		BEGIN
			-- ELIMINAMOS LOS REGISTROS DE LOS OTROS AUDITORES (AEP)
			DELETE FROM [dbo].[AuditorEvaluationPlan] 
				WHERE  [Instance] = @CURRENT_VCC
					AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
					AND [IdAuditor] <> 'SPEECH'

			-- COMPLETAMOS LOS REGISTROS DE ER PARA LAS HABILIDADES MANUALES <- LAS HAB. MANUALES DEBEN QUEDAN EN BLANCO PARA EL AUDITOR SPEECH
			-- EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'MANUAL'

		END

		FETCH NEXT FROM MY_CURSOR_2 INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION
	END
	CLOSE MY_CURSOR_2
	DEALLOCATE MY_CURSOR_2


	-- RECUPERAMOS LAS EVALUACIONES DE SPEECH DE LA TABLA AUDITOR EVALUATION PARA REPLICARLA

	/*
	-- ACTUALIZAMOS EL ESTADO DEL PLAN MIXTO PARA PASAR A LA PARTE MANUAL
	UPDATE EP 
		SET EP.[percentage] = 0
			,EP.[StatusDescription] = 'IN_PROGRESS'
			,EP.[Status] = 8
			,EP.[LastModifiedDate] = GETUTCDATE() 
		FROM [dbo].[EvaluationPlan] AS EP (NOLOCK)
		INNER JOIN [dbo].[#ProgressTemp] PT 
			ON EP.[Instance] = PT.[vcc] 
				AND EP.[ProcessId] = PT.[ProcessId] 
				AND EP.[Id] = PT.[TypeId] 
				AND PT.[Type] = 'ability'
		WHERE EP.[Status] = 7
			AND EP.[Evaluation_Mode] = 'X'
	*/
	

	-- FIN DE ACTUALIZACION DE ESTADO PARA PLANES MIXTOS





	-----------------------------------------------------

	DROP TABLE [dbo].[#ProgressTemp]

END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
