SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[DeleteCustomField] (
	@VCC VARCHAR(50) = NULL, 				
	@CustomFieldId VARCHAR(100) = NULL
) AS
BEGIN
	SET XACT_ABORT, NOCOUNT ON;

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
        
		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- VERIFICAMOS SI EL CUSTOMFIELD ESTA RELACIONADO A ALGUN FORMATO EN USO
		IF EXISTS (
			SELECT DISTINCT --efcf.CustomFieldId,
							EP.[ID],
							EP.[Description]
				FROM [dbo].[EvaluationFormatCustomField] EFCF (NOLOCK)
				LEFT JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[IdEvaluationFormat] = EFCF.[EvaluationFormatId]
				WHERE EFCF.[VCC] = @VCC 
					AND EFCF.[CustomFieldId] = @CustomFieldId
					AND EP.[Instance] IS NOT NULL
		)	
			RAISERROR('DATABABASE_ERROR_CUSTOM_FIELD_ON_USE', 16, 16)

		-- ELIMINAMOS LOS RESULTS DEL CUSTOM FIELD
		DELETE FROM [dbo].[CustomFieldResult] 
			WHERE [VCC] = @VCC 
				AND [CustomFieldId] = @CustomFieldId

		-- ELIMINAMOS EL CUSTOM FIELD
		DELETE FROM [dbo].[CustomField]
			WHERE [VCC] = @VCC 
				AND [ID] = @CustomFieldId
		
		-- RETORNAMOS RESULTADO 1
		SELECT 1 'result'

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
	
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
