SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- ESTE SCRIPT TIENE POR FINALIDAD RETORNAR UN RESUMEN DE LOS AUDIOS EN EL PROCESSID INPUT QUE YA EXISTEN EN UN PROCESSID ANTERIOR
-- DEBIDO A QUE PLANES CREAN EL PROCESS Y EL EVALUATION_PLAN EN DIFERENTES ENDPOINTS, DEJARA DE SER NECESARIO SI SE INTEGRA EL 
-- GUARDADO DE PLAN DE EVALUACION
CREATE PROCEDURE [dbo].[GetAllegroBillingInteractionsForEvaluationPlan] (
	@VCC VARCHAR(50) = NULL,
	@ProcessId VARCHAR(50) = NULL,
	@SecondsPerRequest DECIMAL(18, 5) = NULL
)
AS 
BEGIN 
	-- CREAMOS UNA VARIEBLE PARA ALMACENAR LA FECHA DE CREACION DEL PROCESS INPUT
	--DECLARE @vcc VARCHAR(50) = 'allegro'
	--DECLARE @ProcessId VARCHAR(50) = '3EU91680-UB6U-3GT5-8T50-73474D13WVB8'
	DECLARE @PROCESS_CREATED_DATE DATETIME = NULL

	-- RECUPERAMOS LA FECHA DE CREACION DEL PROCESS INPUT
	SELECT @PROCESS_CREATED_DATE = P.[CreatedDate] 
		FROM [dbo].[Process] P (NOLOCK) 
		WHERE P.[VCC] = @vcc
			AND P.[Name] = @processId;

	-- CREAMOS LAS CTE QUE USAREMOS PARA RECUPERAR EL HISTORICO DE LOS AUDIOS DEL PROCESS INPUT
	WITH CTE_PROCESS_AUDIO AS (
		-- RECUPERAMOS LOS AUDIOS DEL PROCESS INPUT
		SELECT PA.[AudioId],
				PA.[Section],
				PA.[Part]
			FROM [dbo].[ProcessAudio] PA (NOLOCK) 
			WHERE PA.[VCC] = @vcc
				AND PA.[ProcessId] = @processId
	), CTE_PROCESS_AUDIO_2 AS (
		-- CON LA PRIMERA CTE, RECUPERAMOSEL DETALLE DE LOS AUDIOS Y LA CANTIDAD DE VECES QUE SE REPITE EN PROCESS ANTERIORES
		SELECT PA.[AudioId],
				PA.[Section],
				PA.[Part],
				COUNT(*) 'Times' 
			FROM CTE_PROCESS_AUDIO CPA
			LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
				ON PA.[AudioId] = CPA.[AudioId]
					AND PA.[Section] = CPA.[Section]
					AND PA.[Part] = CPA.[Part]
			WHERE PA.[VCC] = @vcc
				AND PA.[CreatedDate] < @PROCESS_CREATED_DATE
			GROUP BY PA.[AudioId], PA.[Section], PA.[Part]
	), CTE_PROCESS_AUDIO_3 AS (
		-- ARMAMOS UNA CTE CON TODOS LOS AUDIOS QUE SE REPITEN Y EL DETALLE DE CADA AUDIO
		SELECT CPA2.[AudioId],
				CPA2.[Section],
				CPA2.[Part],
				A.[DurationTime],
				A.[DurationLinguisticTime],
				A.[IsProcess],
				A.[IsCancel],
				A.[IsTranscribed],
				A.[TotalPhrases]
			FROM CTE_PROCESS_AUDIO_2 CPA2
			LEFT JOIN [dbo].[Audio] A
				ON A.[ID] = CPA2.[AudioId]
					AND A.[Section] = CPA2.[Section]
					AND A.[Part] = CPA2.[Part]
			WHERE A.[VCC] = @vcc
				AND CPA2.[Times] > 0
	)

	SELECT SUM(CASE WHEN PA3.[IsTranscribed] = 1 THEN 1 ELSE 0 END)							'alreadyTranscribedAudio', 
			SUM(CASE WHEN PA3.[IsTranscribed] = 1 THEN PA3.[DurationTime] ELSE 0 END)		'alreadyTranscribedDurationTime',
			SUM(CASE WHEN PA3.[IsTranscribed] IS NULL 
							AND PA3.[IsCancel] IS NULL 
						THEN 1 ELSE 0 END)													'inProcessAudio', 
			SUM(CASE WHEN PA3.[IsTranscribed] IS NULL 
							AND PA3.[IsCancel] IS NULL 
						THEN PA3.[DurationTime] ELSE 0 END)									'inProcessDurationTime', 
			SUM(CASE WHEN PA3.[IsCancel] = 1 THEN 1 ELSE 0 END)								'canceledAudio', 
			SUM(CASE WHEN PA3.[IsCancel] = 1 THEN PA3.[DurationTime] ELSE 0 END)			'canceledDurationTime',
			SUM(CASE WHEN PA3.[IsTranscribed] = 1 
							AND PA3.[TotalPhrases] IS NOT NULL
						THEN PA3.[TotalPhrases] ELSE 0 END)									'totalPhrases',
			SUM(CASE WHEN PA3.[TotalPhrases] IS NULL 
						THEN (PA3.[DurationTime] / @SecondsPerRequest) ELSE 0 END)			'totalRawPhrases' 
		FROM CTE_PROCESS_AUDIO_3 PA3 
	--SELECT * FROM CTE_PROCESS_AUDIO_4
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
