SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetAllegroFilterInteractions]
(
	@Ip						VARCHAR(50),
	@VCC					VARCHAR(50),
	@StartDate				DATETIME = '1980-01-01T00:00:00',
	@EndDate				DATETIME = '2050-01-01T23:59:59',
	@StartHour				VARCHAR(50) = NULL,
	@EndHour				VARCHAR(50) = NULL,
	@Campaign				NVARCHAR(MAX),
	@Agent					NVARCHAR(MAX),
	@ResultCode				NVARCHAR(MAX),
	@Type					INT,
	@Origin					NVARCHAR(MAX),
	@MinDuration			Int,
	@MaxDuration			Int
)
AS
BEGIN
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- DECLARAMOS CADENAS PARA EL QUERY FINAL
	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	
	DECLARE @Sql NVARCHAR(MAX)

	-- CREAMOS LAS VARIABLES QUE HARAN REFERENCIA A LAS TABLAS QUE PUEDEN SER EXTERNAS
	DECLARE @TblHistoricalDataRef NVARCHAR(50) = '';
	DECLARE @TblMmprodataRef NVARCHAR(50) = '';

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF(@Type = 0)  
	BEGIN  
		SET @TblHistoricalDataRef = '[' + @Ip + ']' + '.[HistoricalData].[dbo].'
		SET @TblMmprodataRef = '[' + @Ip + ']' + '.[MMProDat].[dbo].'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @TblHistoricalDataRef = '[HistoricalData].[dbo].'
		SET @TblMmprodataRef = '[MMProDat].[dbo].'
	END


	IF(@Type = 0 OR @Type = 1)  
	BEGIN  
		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA DE RESUMEN
		SET @SQL_SELECT_0 += '
			SET NOCOUNT ON
			SELECT COUNT(DISTINCT ID.[Id])								''totalInteractions'',
					COUNT(*)											''totalAudios'',
					SUM(ID.[AttentionTime])								''totalAttentionTime'' 
				'

		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA DE CONTENIDO
		SET @SQL_SELECT_1 += '
			SET NOCOUNT ON
			SELECT ID.[Id] + ''_'' + CONVERT(VARCHAR(10), IMP.[Section]) + ''_'' + CONVERT(VARCHAR(10), IMP.Part)			''ID'',
					ID.[Id]																									''InteractionId'',
					IMP.[Section]																							''Section'',
					IMP.[Part]																								''Part'',
					''CALL''																								''Channel'',
					CASE WHEN ID.Direction = ''E'' THEN CID.CallerId ELSE CID.CalledId END									''Number'',
					''''																									''Gender'',
					ID.[HoldTime]																							''SilenceTime'',
					ID.[AttentionTime]																						''DurationTime'', -- ESTO SE DEBE CORREGIR
					ID.[AttentionTime]																						''AttentionTime'', -- SE AGREGO CAMPO PARA AMBOS EXISTAN
					ISNULL(CGRM.[Category1], '''')																			''Category1'',
					ISNULL(CGRM.[Category2], '''')																			''Category2'',
					ISNULL(CGRM.[Category3], '''')																			''Category3'',
					ISNULL(CGRM.[Description], '''')																		''Description'',
					ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')															''DispositionCode'',
					ID.[Campaign]																							''Campaign'',
					ID.[LastAgent]																							''Agent'',
					ID.[Direction]																							''Type'',
					CONVERT(VARCHAR, ID.[StartDate], 120)																	''StartDate'',
					CONVERT(VARCHAR, ID.[EndDate], 120)																		''EndDate'',
					IMP.[Format]																							''Format'',
					RN = ROW_NUMBER() OVER(PARTITION BY (ID.[Id] + ''_'' + CONVERT(VARCHAR(10), IMP.[Section]) + ''_'' + CONVERT(VARCHAR(10), IMP.Part)) ORDER BY ID.[Id])
				'
		-- ARMAMOS LA PARTE DE TABLAS 
		SET @SQL_FROM += '
				FROM ' + @TblHistoricalDataRef + '[InteractionMultimediaParts] IMP (NOLOCK)
				LEFT JOIN ' + @TblHistoricalDataRef + '[InteractionDetail] ID (NOLOCK) 
					ON ID.Id = IMP.Id
				LEFT JOIN (
					SELECT VCC, CampaignID, [Order], [Code], 
									[Description], Category1, Category2, Category3 
						FROM ' + @TblMmprodataRef + '[CampaignGoalResultManagement] (NOLOCK)
						WHERE VCC = ''' + @VCC + '''
				) CGRM  
					ON CGRM.VCC = ID.VirtualCC 
						AND CGRM.CampaignId = ID.Campaign 
						AND CGRM.[Description] = ID.ManagementResult
				INNER JOIN ' + @TblHistoricalDataRef + '[CallInteractionDetail] CID (NOLOCK) 
					ON ID.Id = CID.Id 
				'

		-- ARMAMOS LA PARTE BASE DE FILTROS
		SET @SQL_FILTER += '
				WHERE ID.[VirtualCC] = ''' + @VCC + '''
					AND ID.Id IS NOT NULL
					AND id.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + '''
					AND IMP.[Format] in (''mp3'', ''wav'')
					'

		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) SET @SQL_FILTER += 'AND CAST(ID.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' ';
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) SET @SQL_FILTER += 'AND CAST(ID.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' ';
		
		IF(@Campaign IS NOT NULL AND @Campaign <> '') SET @SQL_FILTER += 'AND ID.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaign + ''','','')) ';

		IF(@Agent IS NOT NULL AND @Agent <> '') SET @SQL_FILTER += 'AND ID.[FirstAgent] IN (SELECT Value FROM [dbo].[split](''' + @Agent + ''','','')) ';

		IF(@Origin IS NOT NULL AND @Origin <> '') SET @SQL_FILTER += 'AND ID.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origin + ''','','')) ';

		IF(@MinDuration IS NOT NULL) SET @SQL_FILTER += 'AND ID.[AttentionTime] >= ' + (SELECT CONVERT(varchar(10), @MinDuration)) + ' ';

		IF(@MaxDuration IS NOT NULL) SET @SQL_FILTER += 'AND ID.[AttentionTime] <= ' + (SELECT CONVERT(varchar(10), @MaxDuration)) + ' ';

		IF(@ResultCode IS NOT NULL AND @ResultCode <> '') 
			SET @SQL_FILTER += 'AND (
									(CONCAT(ID.Campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @ResultCode + ''','','')))
									OR
									(ID.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @ResultCode + ''','',''))) 
								) '

		SET @SQL_EXTRA = '
			SET NOCOUNT OFF '

		-- UNIMOS LAS PARTES DEL QUERY
		SET @SQL_SELECT_0 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA
		SET @SQL_SELECT_1 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA


		-- VERIFICAMOS SI EXISTE LA TABLA TEMPORAL #TMP_HD_INTERACTIONS
		IF OBJECT_ID('TEMPDB..#TMP_HD_INTERACTIONS') IS NULL
		BEGIN
			-- CREAMOS UNA TABLA TEMPORAL PARA INSERTAR LOS REGISTROS DE LA HDI6
			CREATE TABLE #TMP_HD_INTERACTIONS
			(
				ID VARCHAR(150),
				InteractionId  VARCHAR(100),
				Section INT,
				Part INT,
				Channel VARCHAR(50),
				Number VARCHAR(100),
				Gender VARCHAR(50),
				SilenceTime INT,
				DurationTime INT,
				AttentionTime INT,
				Category1 VARCHAR(100),
				Category2 VARCHAR(100),
				Category3 VARCHAR(100),
				Description VARCHAR(150),
				DispositionCode INT,
				Campaign VARCHAR(150),
				Agent VARCHAR(100),
				Type VARCHAR(100),
				StartDate VARCHAR(100),
				EndDate VARCHAR(100),
				Format VARCHAR(50),
				RN INT
			)
		END

		-- EJECUTAMOS EL QUERY Y DEPOSITAMOS EL RESULTADO EN UNA TABLA TEMPORAL
		INSERT INTO #TMP_HD_INTERACTIONS
			-- EJECUTAMOS LA CONSULTA
			EXEC (@SQL_SELECT_1)

		-- EJECUTAMOS LAS CONSULTAS
		SELECT COUNT(DISTINCT [InteractionId])					'totalInteractions',
					COUNT(*)									'totalAudios',
					SUM([AttentionTime])						'totalAttentionTime' 
			FROM #TMP_HD_INTERACTIONS
			WHERE RN = 1

		SELECT *
			FROM #TMP_HD_INTERACTIONS
			WHERE RN = 1

		-- ELIMINAMOS LA TABLA TEMPORARL
		DROP TABLE #TMP_HD_INTERACTIONS

		-- EJECUTAMOS LA CONSULTA
		-- EXEC (@SQL_SELECT_0)
		-- EXEC (@SQL_SELECT_1)
	END
	ELSE
	BEGIN
		SET @Sql = 'SELECT 1 AS ''result'''
		EXEC (@Sql)
	END

	

	

	/*
	SET @Sql = ''

	IF(@Type = 0 OR @Type = 1)  
	BEGIN  
		SET @Sql = 'SET NOCOUNT ON
		SELECT
			ID.[Id] + ''_'' + CONVERT(VARCHAR(10), IMP.[Section]) + ''_'' + CONVERT(VARCHAR(10), IMP.Part)			''ID'',
			CASE WHEN ID.Direction = ''E'' THEN CID.CallerId ELSE CID.CalledId END									''Number'',
			''''																									''Gender'',
			ID.[HoldTime]																							''SilenceTime'',
			ID.[AttentionTime]																						''DurationTime'', -- ESTO SE DEBE CORREGIR
			ID.[AttentionTime]																						''AttentionTime'', -- SE AGREGO CAMPO PARA AMBOS EXISTAN
			ISNULL(CGRM.[Category1], '''')																			''Category1'',
			ISNULL(CGRM.[Category2], '''')																			''Category2'',
			ISNULL(CGRM.[Category3], '''')																			''Category3'',
			ISNULL(CGRM.[Description], '''')																		''Description'',
			ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')															''DispositionCode'',
			ID.[Campaign]																							''Campaign'',
			ID.[LastAgent]																							''Agent'',
			ID.[Direction]																							''Type'',
			CONVERT(VARCHAR, ID.[StartDate], 120)																	''StartDate'',
			CONVERT(VARCHAR, ID.[EndDate], 120)																		''EndDate''
		FROM ' + @TblHistoricalDataRef + '[InteractionMultimediaParts] IMP (NOLOCK)
		LEFT JOIN ' + @TblHistoricalDataRef + '[InteractionDetail] ID (NOLOCK) 
			ON ID.Id = IMP.Id
		LEFT JOIN (
			SELECT TOP 1 VCC, CampaignID, [Order], [Code], 
							[Description], Category1, Category2, Category3 
				FROM ' + @TblMmprodataRef + '[CampaignGoalResultManagement] (NOLOCK)
		) CGRM  
			ON CGRM.VCC = ID.VirtualCC 
				AND CGRM.CampaignId = ID.Campaign 
				AND CGRM.[Description] = ID.ManagementResult
		INNER JOIN ' + @TblHistoricalDataRef + '[CallInteractionDetail] CID (NOLOCK) 
			ON ID.Id = CID.Id
		WHERE ID.[VirtualCC] = ''' + @VCC + '''
			AND ID.Id IS NOT NULL
			AND ID.[EndDate] >= ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + '''
			AND ID.[EndDate] <= ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' 
			AND IMP.[Format] in (''mp3'', ''wav'') '
		
		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) SET @Sql += 'AND CAST(ID.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' ';
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) SET @Sql += 'AND CAST(ID.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' ';
		
		IF(@Campaign IS NOT NULL AND @Campaign <> '')
		SET @Sql += 'AND ID.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaign + ''','','')) ';

		IF(@Agent IS NOT NULL AND @Agent <> '')
		SET @Sql += 'AND ID.[FirstAgent] IN (SELECT Value FROM [dbo].[split](''' + @Agent + ''','','')) ';

		IF(@Origin IS NOT NULL AND @Origin <> '')
		SET @Sql += 'AND ID.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origin + ''','','')) ';

		IF(@MinDuration IS NOT NULL)
		SET @Sql += 'AND ID.[AttentionTime] >= ' + (SELECT CONVERT(varchar(10), @MinDuration)) + ' ';

		IF(@MaxDuration IS NOT NULL)
		SET @Sql += 'AND ID.[AttentionTime] <= ' + (SELECT CONVERT(varchar(10), @MaxDuration)) + ' ';

		IF(@ResultCode IS NOT NULL AND @ResultCode <> '')
		SET @Sql += '
		AND CONCAT(ID.Campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @ResultCode + ''','',''))'

 		SET @Sql += '
		SET NOCOUNT OFF '
	END
	ELSE
	BEGIN
		SET @Sql = 'SELECT 1 AS ''result'''
	END

	EXEC (@Sql)
	*/
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
