SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetStudyResultSummary]
(
	@VCC					VARCHAR(50),
	@StudyId				VARCHAR(200),
	@NewStructure			VARCHAR(1)
)
AS
BEGIN
	SET NOCOUNT ON

	BEGIN
		SELECT
			B.[Name]						'processName',
			A.[Name]						'studyName',
			A.[Description]					'studyDescription',
			A.[TemplateId]					'templateId'
		FROM [dbo].[Study] A (NOLOCK)
		INNER JOIN Process B ON A.ProcessId = B.[Name]
		WHERE A.[VCC] = @VCC 
			AND A.[Name] = @StudyId
	END

	BEGIN
		SELECT
			[VCC]							'vcc',
			[StudyId]						'studyId',
			[TemplateId]					'templateId',
			[TemplateThemeId]				'templateThemeId',
			[ID]							'id',
			[Description]					'description',
			[Category1]						'category1',
			[Category2]						'category2',
			[Total]							'total',
			[Duration]						'duration',
			[Silence]						'silence',
			[Confidence]					'confidence',
			[CreatedDate]					'createdDate',
			[CreatedByUserId]				'createdByUserId',
			[LastModifiedDate]				'lastModifiedDate',
			[LastModifiedByUserId]			'lastModifiedByUserId'
		FROM [dbo].[StudyResultSummary] (NOLOCK)
		WHERE [VCC] = @VCC 
			AND [StudyId] = @StudyId
	END

	IF(@NewStructure IS NULL)
	BEGIN
		SELECT
			A.[TemplateThemeId]									'templateThemeId',
			A.[TemplateThemeItemId]								'templateThemeItemId',
			ISNULL(D.[Query], A.[TemplateThemeItemId])			'query', -- Si es NULL se mostrara valor de TemplateThemeItem campo ID.
			ISNULL(C.[Channel], AI.[Channel])					'interactionType',
			-- REPLACE(A.[TranscriptionId], '_0_1', '')			'transcriptionId',

			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN REPLACE(A.[TranscriptionId], '_0_1', '') 
				ELSE AI.[ID] END								'transcriptionId',

			C.[Section]											'section',
			C.[Part]											'part',
			AI.[Folder]											'folder',
			AI.[Campaign]										'campaign',
			--ISNULL(C.[Agent], '')								'agent'
			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[Agent], '') 
				ELSE ISNULL(AI.[FirstTakedAgent], '') END		'agent',
			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[IsTranscribed], '') 
				ELSE ISNULL(AI.[IsTranscribed], '') END			'isTranscribed',
			CASE WHEN C.[Channel] IS NOT NULL
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[IsCancel], '') 
				ELSE ISNULL(AI.[IsCancel], '') END				'isCancel'
		FROM 
			[dbo].[StudyResultSummaryDetail] A (NOLOCK)
			INNER JOIN [dbo].[Study] S (NOLOCK) 
				ON S.[VCC] = A.[VCC] 
					AND S.[Name] = A.[StudyId]
			INNER JOIN [dbo].[TemplateThemeItem] B (NOLOCK) 
				ON S.[TemplateId] = B.[TemplateId] 
					AND A.[TemplateThemeId] = B.[TemplateThemeId] 
					AND A.[TemplateThemeItemId] = B.[ID]
			
			LEFT JOIN [dbo].[Audio] C (NOLOCK)  -- (!)SE CAMBIO EL INNER POR LEFT PARA CONSIDER LAS TRANSCRIPCIONES DE CANALES ASINCRINOS
				ON A.[TranscriptionId] = CONCAT(C.[ID], '_', C.[Section], '_', C.[Part])
			LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
				ON S.[VCC] = PA.[VCC] 
					AND S.[ProcessId] = PA.[ProcessId] 
					AND A.[TranscriptionId] = CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part])

			LEFT JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON A.[TranscriptionId] = CONCAT(AI.[Channel], '_', AI.[Campaign], '_', AI.[Folder], '_', REPLACE(AI.[ID], ':', '_'))
			LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
				ON PAI.[VCC] = S.[VCC]
					AND PAI.[ProcessId] = S.[ProcessId]
					AND CONCAT(PAI.[InteractionType], '_', PAI.[Campaign], '_', PAI.[FormattedEndDate], '_', REPLACE(PAI.[InteractionId], ':', '_')) = A.[TranscriptionId]

			LEFT JOIN [dbo].[GenericQuery] D (NOLOCK) 
				ON B.[VCC] = D.[VCC] 
					AND  B.[ID] = D.[Name] -- Se agrega LEFT JOIN para poder mostrar.
		WHERE
			B.[VCC] IN ('system', @VCC) AND
			A.[StudyId] = @StudyId
	END
	ELSE
	BEGIN
		-- ESTE BLOQUE NUNCA SE USA, EL UNICO LLAMADO DE LA FUNCION INSERTA DIRECTAMENTE NULL PARA LA VARIABLE @NewStructure
		SELECT
			A.[TemplateThemeId]									'templateThemeId',
			A.[TemplateThemeItemId]								'templateThemeItemId',
			D.[Query]											'query',
			ISNULL(C.[Channel], AI.[Channel])					'interactionType',
			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN A.[TranscriptionId] 
				ELSE AI.[ID] END								'transcriptionId',
			C.[Section]											'section',
			C.[Part]											'part',
			AI.[Folder]											'folder',
			AI.[Campaign]										'campaign',
			--ISNULL(C.[Agent], '')								'agent',
			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[Agent], '') 
				ELSE ISNULL(AI.[FirstTakedAgent], '') END		'agent',
			CASE WHEN C.[Channel] IS NOT NULL 
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[IsTranscribed], '') 
				ELSE ISNULL(AI.[IsTranscribed], '') END			'isTranscribed',
			CASE WHEN C.[Channel] IS NOT NULL
					AND C.[Channel] = 'CALL' 
				THEN ISNULL(C.[IsCancel], '') 
				ELSE ISNULL(AI.[IsCancel], '') END				'isCancel'
			
		FROM 
			[dbo].[StudyResultSummaryDetail] A (NOLOCK)
			INNER JOIN [dbo].[Study] S (NOLOCK) 
				ON S.[VCC] = A.[VCC] 
					AND S.[Name] = A.[StudyId]
			INNER JOIN [dbo].[TemplateThemeItem] B (NOLOCK) 
				ON S.[TemplateId] = B.[TemplateId] 
					AND A.[TemplateThemeId] = B.[TemplateThemeId] 
					AND A.[TemplateThemeItemId] = B.[ID]
			
			LEFT JOIN [dbo].[Audio] C (NOLOCK) 
				ON A.[TranscriptionId] = CONCAT(C.[ID], '_', C.[Section], '_', C.[Part])
			INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
				ON S.[VCC] = PA.[VCC] 
					AND S.[ProcessId] = PA.[ProcessId] 
					AND A.[TranscriptionId] = CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part])
			
			LEFT JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON A.[TranscriptionId] = CONCAT(AI.[Channel], '_', AI.[Campaign], '_', AI.[Folder], '_', REPLACE(AI.[ID], ':', '_'))
			LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
				ON PAI.[VCC] = S.[VCC]
					AND PAI.[ProcessId] = S.[ProcessId]
					AND CONCAT(PAI.[InteractionType], '_', PAI.[Campaign], '_', PAI.[FormattedEndDate], '_', REPLACE(PAI.[InteractionId], ':', '_')) = A.[TranscriptionId]

			INNER JOIN [dbo].[GenericQuery] D (NOLOCK) 
				ON B.[VCC] = D.[VCC] 
					AND  B.[ID] = D.[Name]
		WHERE
			B.[VCC] IN ('system', @VCC) AND
			A.[StudyId] = @StudyId
	END
	
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
