SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
--exec [GetTemplates] 'system','template','name',''
CREATE PROCEDURE [dbo].[GetTemplates] (
	@VCC Varchar(50) = NULL,	@Type Varchar(50) = NULL,	@SearchCriteria Varchar(50) = NULL,	@SearchExpression Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON;

	-- CREAMOS LAS CTE QUE USAREMOS PARA RECUPERAR LOS MODELOS DE LAS PLANTILLAS
	WITH CTE_TEMPLATE_NLUS AS (
		SELECT DISTINCT TTI.[VCC]
						, TTI.[TemplateId]
						--, TTI.[TemplateThemeId]
						--, TTI.[ID]
						, N.[AppID]
						, N.[Name]
						, N.[Culture]
			FROM [TemplateThemeItem] TTI (NOLOCK)
			LEFT JOIN [dbo].[GenericQuery] GQ (NOLOCK) 
				ON GQ.[VCC] = TTI.[VCC]
					AND GQ.[Name] = TTI.[ID] 
					AND GQ.[VCC] = TTI.[VCC]
			INNER JOIN [dbo].[NLU] N (NOLOCK) 
				ON N.[VCC] = TTI.[VCC] 
					AND N.[Name] = SUBSTRING(TTI.[ID], 0, CHARINDEX('|', TTI.[ID]))
			WHERE TTI.[VCC] IN (@VCC, 'system')
				AND TTI.[ID] LIKE '%|%'
				AND GQ.[Query] IS NULL
	)

	SELECT
		T.[Type]																'type',
		T.[Name]																'name',
		T.[Description]															'description',
		T.[Template]															'template',
		T.[Category]															'category',
		STUFF((
			SELECT ',' + CTN_INNER.[Culture]
				FROM CTE_TEMPLATE_NLUS CTN_INNER (NOLOCK)
				WHERE CTN_INNER.[TemplateId] = T.[Name]
		FOR XML PATH(''), TYPE).value('.', 'NVARCHAR(MAX)'), 1, 1, '')			'modelLanguages',
		T.[CreatedDate]															'createdDate',
		T.[CreatedByUserId]														'createdByUserId',
		T.[LastModifiedDate]													'lastModifiedDate',
		T.[LastModifiedByUserId]												'lastModifiedByUserId'
	FROM [Template] T (NOLOCK)
	WHERE T.[VCC] IN (@VCC, 'system')
		AND T.[Type] = CASE WHEN ISNULL(@Type, '') = '' THEN T.[Type] ELSE @Type END
		AND T.[Type] IN ('system','custom')
		AND ISNULL(T.[Name], '') LIKE CASE WHEN @SearchCriteria = 'name' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Category], '') LIKE CASE WHEN @SearchCriteria = 'category' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Type], '') LIKE CASE WHEN @SearchCriteria = 'type' THEN '%' + @SearchExpression + '%' ELSE '%' END
	ORDER BY T.[Name] asc, T.[CreatedDate] desc 

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
