SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- ESTA FUNCION CAMBIA EL ESTADO DE UN BATCH DEL SISTEMA
CREATE PROCEDURE [dbo].[SaveBatchStatus] (
	@VCC VARCHAR(50) = NULL,
	@BatchTypeId VARCHAR(100) = NULL,
	@SystemService VARCHAR(50) = NULL,
	@Status VARCHAR(50) = NULL
	)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE ACTUALIZAR LOS SALDOS DE LAS CARTERAS DEL VCC
	SET XACT_ABORT, NOCOUNT ON

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
		
		-- VALIDAMOS QUE TENEMOS LOS PARAMETROS NECESARIOS
		IF @VCC IS NULL 
			OR @BatchTypeId IS NULL 
			OR @Status IS NULL
			-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
			RAISERROR('DATABASE_ERROR_MISSING_PARAMETERS', 16, 16)

		-- VERIFICAMOS QUE EL BATCH TYPE SEA UN TIPO CONOCIDO DEL SISTEMA
		IF @SystemService <> 'TRANSCRIPTION' AND @SystemService <> 'SEMANTIC_ANALYSIS' AND @SystemService <> 'COGNITIVE_ANALYSIS'
			-- LANZAMOS MENSAJE AVISANDO QUE HAN SOLICITADO UNA OPERACION DESCONOCIDA
			RAISERROR('DATABASE_ERROR_UNKNOWN_SYSTEM_SERVICE', 16, 16)

		-- DECLARAMOS UNA VARIABLE PARA TIPO DE BATCH CORRESPONDIENTE AL BATCHTYPEID
		DECLARE @BATCH_TYPE_NAME VARCHAR(50) = NULL

		-- IDENTIFICAMOS EL TIPO BATCH SEGUN EL BATCHTYPEID Y SERVICIO DEL SISTEMA
		IF @SystemService = 'TRANSCRIPTION'
		BEGIN
			-- VERIFICAMOS SI ES DEL TIPO PROCESS
			IF EXISTS (SELECT 1 FROM [dbo].[Process] P WHERE [VCC] = @VCC AND [Name] = @BatchTypeId)
				SET @BATCH_TYPE_NAME = 'TRANSCRIPTION'

			-- VERIFICAMOS SI ES DEL TIPO EVALUATION_PLAN
			IF EXISTS (SELECT 1 FROM [dbo].[EvaluationPlan] P WHERE [Instance] = @VCC AND [ID] = @BatchTypeId)
				SET @BATCH_TYPE_NAME = 'EVALUATION_PLAN'
		END
		ELSE IF @SystemService = 'SEMANTIC_ANALYSIS'
		BEGIN
			-- VERIFICAMOS SI ES DEL TIPO STUDY
			IF EXISTS (SELECT 1 FROM [dbo].[Study] P WHERE [VCC] = @VCC AND [Name] = @BatchTypeId)
				SET @BATCH_TYPE_NAME = 'STUDY'

			-- VERIFICAMOS SI ES DEL TIPO EVALUATION_PLAN
			IF EXISTS (SELECT 1 FROM [dbo].[EvaluationPlan] P WHERE [Instance] = @VCC AND [ID] = @BatchTypeId)
				SET @BATCH_TYPE_NAME = 'EVALUATION_PLAN'
		END
		ELSE IF @SystemService = 'COGNITIVE_ANALYSIS'
		BEGIN
			-- VERIFICAMOS SI ES DEL TIPO STUDY
			IF EXISTS (SELECT 1 FROM [dbo].[Study] P WHERE [VCC] = @VCC AND [Name] = @BatchTypeId)
				SET @BATCH_TYPE_NAME = 'STUDY'

			-- VERIFICAMOS SI ES DEL TIPO EVALUATION_PLAN
			IF EXISTS (SELECT 1 FROM [dbo].[EvaluationPlan] P WHERE [Instance] = @VCC AND [ID] = @BatchTypeId)
				SET @BATCH_TYPE_NAME = 'EVALUATION_PLAN'
		END
		
		-- VERIFICAMOS QUE EL BATCH TYPE SEA UN TIPO CONOCIDO DEL SISTEMA
		IF @BATCH_TYPE_NAME <> 'TRANSCRIPTION' AND @BATCH_TYPE_NAME <> 'STUDY' AND @BATCH_TYPE_NAME <> 'EVALUATION_PLAN'
			-- LANZAMOS MENSAJE AVISANDO QUE HAN SOLICITADO UNA OPERACION DESCONOCIDA
			RAISERROR('DATABASE_ERROR_UNKNOWN_BATCH_TYPE', 16, 16)

		-- ACTUALIZAMOS EL BATCH SEGUN EL SERVICIO DEL SISTEMA
		IF @BATCH_TYPE_NAME = 'TRANSCRIPTION'
		BEGIN
			-- ACTUALIZAMOS EL REGISTRO DE PROCESS
			UPDATE [dbo].[Process] 
				SET [StatusDescription] = @Status, 
					[Status] = @Status 
				WHERE [VCC] = @VCC
					AND [Name] = @BatchTypeId
		END 
		ELSE IF @BATCH_TYPE_NAME = 'STUDY'
		BEGIN
			-- ACTUALIZAMOS EL REGISTRO DE STUDY
			UPDATE [dbo].[Study] 
				SET [StatusDescription] = @Status, 
					[BatchStatus] = @Status,
					[LastModifiedDate] = CURRENT_TIMESTAMP,
					[TimeStamp] = CURRENT_TIMESTAMP 
				WHERE [VCC] = @VCC
					AND [Name] = @BatchTypeId
		END
		ELSE IF @BATCH_TYPE_NAME = 'EVALUATION_PLAN'
		BEGIN
			-- ACTUALIZAMOS EL REGISTRO DE EVALUATION_PLAN
			UPDATE [dbo].[EvaluationPlan] 
				SET [StatusDescription] = @Status, 
					-- [Status] = @Status, 
					[LastModifiedDate] = CURRENT_TIMESTAMP,
					[TimeStamp] = CURRENT_TIMESTAMP
				WHERE [Instance] = @VCC
					AND [ID] = @BatchTypeId
		END

		-- VERIFICAMOS SI SE ACTUALIZO EL REGISTRO
		IF @@ROWCOUNT = 0
			RAISERROR('DATABASE_ERROR_BATCH_SUMMARY_STATUS_UPDATE_FAILED', 16, 16)

		-- RETORNAMOS RESULTADO 1
		SELECT 1 'result'

	END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

	SET XACT_ABORT, NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
